# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/notify/notification_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.notify import notification_pb2 as eolymp_dot_notify_dot_notification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/notify/notification_service.proto\x12\reolymp.notify\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a eolymp/notify/notification.proto\"L\n\x17\x43reateNotificationInput\x12\x31\n\x0cnotification\x18\x01 \x01(\x0b\x32\x1b.eolymp.notify.Notification\"\x1a\n\x18\x43reateNotificationOutput\"4\n\x19\x44\x65scribeNotificationInput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"O\n\x1a\x44\x65scribeNotificationOutput\x12\x31\n\x0cnotification\x18\x01 \x01(\x0b\x32\x1b.eolymp.notify.Notification\"0\n\x15ReadNotificationInput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"\x18\n\x16ReadNotificationOutput\"2\n\x17\x44\x65leteNotificationInput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteNotificationOutput\"5\n\x16ListNotificationsInput\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\"T\n\x17ListNotificationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.notify.Notification\"!\n\x1f\x44\x65scribeNotificationConfigInput\"?\n DescribeNotificationConfigOutput\x12\x1b\n\x13\x65mail_subscriptions\x18\x02 \x03(\t\"<\n\x1dUpdateNotificationConfigInput\x12\x1b\n\x13\x65mail_subscriptions\x18\x02 \x03(\t\" \n\x1eUpdateNotificationConfigOutput2\xd9\x08\n\x13NotificationService\x12v\n\x12\x43reateNotification\x12&.eolymp.notify.CreateNotificationInput\x1a\'.eolymp.notify.CreateNotificationOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12\xa4\x01\n\x14\x44\x65scribeNotification\x12(.eolymp.notify.DescribeNotificationInput\x1a).eolymp.notify.DescribeNotificationOutput\"7\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"\x12 /notifications/{notification_id}\x12\x9d\x01\n\x10ReadNotification\x12$.eolymp.notify.ReadNotificationInput\x1a%.eolymp.notify.ReadNotificationOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\"%/notifications/{notification_id}/read\x12\x9e\x01\n\x12\x44\x65leteNotification\x12&.eolymp.notify.DeleteNotificationInput\x1a\'.eolymp.notify.DeleteNotificationOutput\"7\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"* /notifications/{notification_id}\x12\x89\x01\n\x11ListNotifications\x12%.eolymp.notify.ListNotificationsInput\x1a&.eolymp.notify.ListNotificationsOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\x12\x0e/notifications\x12\xac\x01\n\x1a\x44\x65scribeNotificationConfig\x12..eolymp.notify.DescribeNotificationConfigInput\x1a/.eolymp.notify.DescribeNotificationConfigOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\x12\x16/configs/notifications\x12\xa6\x01\n\x18UpdateNotificationConfig\x12,.eolymp.notify.UpdateNotificationConfigInput\x1a-.eolymp.notify.UpdateNotificationConfigOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\"\x16/configs/notificationsB/Z-github.com/eolymp/go-sdk/eolymp/notify;notifyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.notify.notification_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/notify;notify'
  _NOTIFICATIONSERVICE.methods_by_name['CreateNotification']._options = None
  _NOTIFICATIONSERVICE.methods_by_name['CreateNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _NOTIFICATIONSERVICE.methods_by_name['DescribeNotification']._options = None
  _NOTIFICATIONSERVICE.methods_by_name['DescribeNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"\022 /notifications/{notification_id}'
  _NOTIFICATIONSERVICE.methods_by_name['ReadNotification']._options = None
  _NOTIFICATIONSERVICE.methods_by_name['ReadNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\'\"%/notifications/{notification_id}/read'
  _NOTIFICATIONSERVICE.methods_by_name['DeleteNotification']._options = None
  _NOTIFICATIONSERVICE.methods_by_name['DeleteNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"* /notifications/{notification_id}'
  _NOTIFICATIONSERVICE.methods_by_name['ListNotifications']._options = None
  _NOTIFICATIONSERVICE.methods_by_name['ListNotifications']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\020\022\016/notifications'
  _NOTIFICATIONSERVICE.methods_by_name['DescribeNotificationConfig']._options = None
  _NOTIFICATIONSERVICE.methods_by_name['DescribeNotificationConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\030\022\026/configs/notifications'
  _NOTIFICATIONSERVICE.methods_by_name['UpdateNotificationConfig']._options = None
  _NOTIFICATIONSERVICE.methods_by_name['UpdateNotificationConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\030\"\026/configs/notifications'
  _CREATENOTIFICATIONINPUT._serialized_start=160
  _CREATENOTIFICATIONINPUT._serialized_end=236
  _CREATENOTIFICATIONOUTPUT._serialized_start=238
  _CREATENOTIFICATIONOUTPUT._serialized_end=264
  _DESCRIBENOTIFICATIONINPUT._serialized_start=266
  _DESCRIBENOTIFICATIONINPUT._serialized_end=318
  _DESCRIBENOTIFICATIONOUTPUT._serialized_start=320
  _DESCRIBENOTIFICATIONOUTPUT._serialized_end=399
  _READNOTIFICATIONINPUT._serialized_start=401
  _READNOTIFICATIONINPUT._serialized_end=449
  _READNOTIFICATIONOUTPUT._serialized_start=451
  _READNOTIFICATIONOUTPUT._serialized_end=475
  _DELETENOTIFICATIONINPUT._serialized_start=477
  _DELETENOTIFICATIONINPUT._serialized_end=527
  _DELETENOTIFICATIONOUTPUT._serialized_start=529
  _DELETENOTIFICATIONOUTPUT._serialized_end=555
  _LISTNOTIFICATIONSINPUT._serialized_start=557
  _LISTNOTIFICATIONSINPUT._serialized_end=610
  _LISTNOTIFICATIONSOUTPUT._serialized_start=612
  _LISTNOTIFICATIONSOUTPUT._serialized_end=696
  _DESCRIBENOTIFICATIONCONFIGINPUT._serialized_start=698
  _DESCRIBENOTIFICATIONCONFIGINPUT._serialized_end=731
  _DESCRIBENOTIFICATIONCONFIGOUTPUT._serialized_start=733
  _DESCRIBENOTIFICATIONCONFIGOUTPUT._serialized_end=796
  _UPDATENOTIFICATIONCONFIGINPUT._serialized_start=798
  _UPDATENOTIFICATIONCONFIGINPUT._serialized_end=858
  _UPDATENOTIFICATIONCONFIGOUTPUT._serialized_start=860
  _UPDATENOTIFICATIONCONFIGOUTPUT._serialized_end=892
  _NOTIFICATIONSERVICE._serialized_start=895
  _NOTIFICATIONSERVICE._serialized_end=2008
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Class(_message.Message):
    __slots__ = ["assign_all", "group_id", "id", "inactive", "name"]
    ASSIGN_ALL_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    assign_all: bool
    group_id: str
    id: str
    inactive: bool
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., group_id: _Optional[str] = ..., inactive: bool = ..., assign_all: bool = ...) -> None: ...
